use strict;
use warnings;
 
use Test::More tests => 5;
 
use_ok 'App::PhotoDB';
use_ok 'App::PhotoDB::commands';
use_ok 'App::PhotoDB::funcs';
use_ok 'App::PhotoDB::handlers';
use_ok 'App::PhotoDB::queries';

done_testing();
